# Table of Contents

- [scheduled-changes](<./scheduled-changes.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Scheduled Changes](<./Scheduled-Changes.md>)
  - [Introduction](<./Scheduled-Changes/Introduction.md>)
  - [Activating the Scheduled Change Feature](<./Scheduled-Changes/Activating-the-Scheduled-Change-Feature.md>)
  - [Viewing Scheduled Changes](<./Scheduled-Changes/Viewing-Scheduled-Changes.md>)
  - [Scheduling Changes](<./Scheduled-Changes/Scheduling-Changes.md>)
  - [Scheduling Changes for Fact Sheet Fields](<./Scheduled-Changes/Scheduling-Changes-for-Fact-Sheet-Fields.md>)
  - [Scheduling Changes for Fact Sheet Relations](<./Scheduled-Changes/Scheduling-Changes-for-Fact-Sheet-Relations.md>)
  - [Deleting Scheduled Changes](<./Scheduled-Changes/Deleting-Scheduled-Changes.md>)
